OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "埋め込みメッセージ%s",
    "Important mail" : "重要なメール",
    "No message found yet" : "メッセージはまだありません。",
    "Set up an account" : "アカウントを設定",
    "Unread mail" : "未読メール",
    "Important" : "重要",
    "Work" : "仕事",
    "Personal" : "個人",
    "To Do" : "To Do",
    "Later" : "後で",
    "Mail" : "メール",
    "You are reaching your mailbox quota limit for {account_email}" : "あなたの{account_email}メールボックスのクォータ制限が上限に達しています。",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "現在、メールボックスストレージの{percentage}を使用しています。不要なメールを削除してスペースを空けてください。",
    "Mail Application" : "アプリケーションをメール",
    "Mails" : "メール",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "送信者の電子メール: %1$s はアドレス帳にありませんが、送信者名: %2$s は次の電子メールと共にアドレス帳にあります: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "送信者の電子メール: %1$s はアドレス帳にありませんが、送信者名: %2$s は次の電子メールと共にアドレス帳にあります: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "送信者は、送信者の電子メール: %2$s ではなくカスタム電子メール: %1$s を使用しています",
    "Sent date is in the future" : "送信日が未来の日付です",
    "Some addresses in this message are not matching the link text" : "このメッセージの一部のアドレスがリンクテキストと一致しません",
    "Reply-To email: %1$s  is different from the sender email: %2$s" : "返信先の電子メール: %1$s は送信者の電子メール: %2$s と異なります",
    "Mail Transport configuration" : "メール転送の設定",
    "The app.mail.transport setting is not set to smtp. This configuration can cause issues with modern email security measures such as SPF and DKIM because emails are sent directly from the web server, which is often not properly configured for this purpose. To address this, we have discontinued support for the mail transport. Please remove app.mail.transport from your configuration to use the SMTP transport and hide this message. A properly configured SMTP setup is required to ensure email delivery." : "app.mail.transport設定がsmtpに設定されていません。この設定は、SPFやDKIMといった最新の電子メールセキュリティ対策で問題を引き起こす可能性があります。なぜなら、電子メールはWebサーバーから直接送信されるため、この目的のために適切に設定されていないことが多いからです。この問題に対処するため、メールトランスポートのサポートを終了しました。SMTPトランスポートを使用し、このメッセージを非表示にするには、設定からapp.mail.transportを削除してください。メール配信を確実に行うには、SMTPを適切に設定する必要があります。",
    "💌 A mail app for Nextcloud" : "💌Nextcloudのメールアプリ",
    "Your session has expired. The page will be reloaded." : "あなたのセッションは期間切れています。ページを再リロードしてください",
    "Drafts are saved in:" : "下書きの保存先:",
    "Sent messages are saved in:" : "送信済みの保存先:",
    "Deleted messages are moved in:" : "削除されたメッセージの移動先:",
    "Archived messages are moved in:" : "アーカイブ済みのメッセージは次の場所に移動されます:",
    "Snoozed messages are moved in:" : "スヌーズメッセージを移動する:",
    "Junk messages are saved in:" : "迷惑メッセージが保存済み:",
    "Connecting" : "接続中",
    "Reconnect Google account" : "Googleアカウントと再接続",
    "Sign in with Google" : "Googleでサインイン",
    "Reconnect Microsoft account" : "Microsoftアカウントの再接続",
    "Sign in with Microsoft" : "Microsoftでサインインする",
    "Save" : "保存",
    "Connect" : "接続",
    "Looking up configuration" : "設定の検索",
    "Checking mail host connectivity" : "メールホストの接続を確認しています",
    "Configuration discovery failed. Please use the manual settings" : "設定検出が失敗しました。手動で設定を行ってください",
    "Password required" : "パスワードが必要です",
    "Testing authentication" : "認証のテスト",
    "Awaiting user consent" : "ユーザーの同意を待機中です",
    "Account created. Please follow the pop-up instructions to link your Google account" : "アカウントが作成されました。Googleアカウントをリンクするには、ポップアップの指示に従ってください",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "アカウントが作成されました。ポップアップの指示に従って、Microsoftアカウントをリンクしてください。",
    "Loading account" : "アカウントを読み込み中",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "アカウントが更新されました。ポップアップの指示に従って、Googleアカウントを再接続してください。",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "アカウントが更新されました。ポップアップの指示に従って、Microsoftアカウントを再接続してください。",
    "Account updated" : "アカウントが更新されました",
    "IMAP server is not reachable" : "IMAPサーバーにアクセスできません",
    "SMTP server is not reachable" : "SMTPサーバーにアクセスできません",
    "IMAP username or password is wrong" : "IMAP ユーザー名またはパスワードが間違っています",
    "SMTP username or password is wrong" : "SMTP ユーザー名またはパスワードが間違っています",
    "IMAP connection failed" : "IMAP 接続が失敗しました",
    "SMTP connection failed" : "SMTP接続が失敗しました",
    "Authorization pop-up closed" : "承認ポップアップは閉じました",
    "Configuration discovery temporarily not available. Please try again later." : "設定の検出は一時的に利用できません。後でもう一度やり直してください。",
    "There was an error while setting up your account" : "アカウントの設定中にエラーが発生しました",
    "Auto" : "自動",
    "Name" : "名前",
    "Mail address" : "メールアドレス",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "name@example.com形式のメールを入力してください。",
    "Password" : "パスワード",
    "Manual" : "手動",
    "IMAP Settings" : "IMAP設定",
    "IMAP Host" : "IMAPホスト",
    "IMAP Security" : "IMAPセキュリティ",
    "None" : "なし",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAPポート",
    "IMAP User" : "IMAPユーザー",
    "IMAP Password" : "IMAPパスワード",
    "SMTP Settings" : "SMTP設定",
    "SMTP Host" : "SMTPホスト",
    "SMTP Security" : "SMTPセキュリティ",
    "SMTP Port" : "SMTPポート",
    "SMTP User" : "SMTPユーザー",
    "SMTP Password" : "SMTPパスワード",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Googleアカウントでこのアプリを使用するには、Googleの2要素認証を有効にし、アプリパスワードを生成する必要があります。",
    "Account settings" : "アカウント設定",
    "Aliases" : "別名",
    "Alias to S/MIME certificate mapping" : "エイリアスから S/MIME 証明書へのマッピング",
    "Signature" : "署名",
    "A signature is added to the text of new messages and replies." : "署名は、新しいメッセージと返信の本文に追加されます。",
    "Writing mode" : "書き込みモード",
    "Preferred writing mode for new messages and replies." : "新しいメッセージと返信に使うお好みの書き込みモード",
    "Default folders" : "デフォルトフォルダー",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "下書き、送信済みメッセージ、削除済みメッセージ、アーカイブ済みメッセージ、および迷惑メッセージに使用するフォルダー。",
    "Automatic trash deletion" : "ゴミ箱の自動削除",
    "Days after which messages in Trash will automatically be deleted:" : "ゴミ箱内のメッセージは何日後に自動的に削除されます",
    "Autoresponder" : "自動返信",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "受信メッセージへの自動返信。複数のメッセージが送信された場合、この自動返信は最大で4日に1回送信されます。",
    "Filters" : "フィルター",
    "Sieve script editor" : "Sieveスクリプトエディタ",
    "Mail server" : "メールサーバー",
    "Sieve server" : "Sieveサーバー",
    "Update alias" : "エイリアスを更新する",
    "Rename alias" : "エイリアスの名前を変更する",
    "Show update alias form" : "エイリアスの更新フォームを表示する",
    "Delete alias" : "別名を削除",
    "Go back" : "戻る",
    "Change name" : "名称変更",
    "Email address" : "メールアドレス",
    "Add alias" : "別名を追加",
    "Create alias" : "別名をつける",
    "Cancel" : "キャンセル",
    "Search in the body of messages in priority Inbox" : "優先受信箱のメッセージ本文を検索します",
    "Activate" : "有効化する",
    "Put my text to the bottom of a reply instead of on top of it." : "返信をメール本文の先頭ではなく最後に挿入します。",
    "Mark as important" : "重要としてマークをつける",
    "Remind about messages that require a reply but received none" : "返信を必要とするが受信しなかったメッセージについて通知する",
    "Use internal addresses" : "内部アドレスを使う",
    "Could not update preference" : "環境設定を更新できませんでした",
    "Mail settings" : "メール設定",
    "Accounts" : "アカウント",
    "Add mail account" : "メールアカウントを追加",
    "Settings for:" : "次の設定:",
    "General" : "一般",
    "Layout" : "レーアウト",
    "List" : "リスト",
    "Vertical split" : "垂直分割",
    "Horizontal split" : "水平分割",
    "Sorting" : "並べ替え",
    "Newest" : "最新",
    "Oldest" : "最古",
    "Search in body" : "本文を検索",
    "Reply text position" : "返信テキストの位置",
    "Gravatar settings" : "グラバター設定",
    "Use Gravatar and favicon avatars" : "Gravatarとfaviconのアバターを使用する",
    "Mailto" : "メールアドレス",
    "Register as application for mail links" : "メールリンクのアプリケーションとして新規登録する",
    "Register" : "登録",
    "Privacy and security" : "プライバシーとセキュリティ",
    "Data collection consent" : "データ収集の同意",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "操作手順についてのデータ収集をアプリに許可します。このデータに基づき、アプリがあなた好みに適応します。データはローカルにしか保存されません。",
    "Trusted senders" : "信頼できる送信先",
    "Internal addresses" : "内部アドレス",
    "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "外部メールアドレスを強調表示この機能を有効にすると、内部のアドレスとドメインを管理し、認識された連絡先がマークされないようになります。",
    "S/MIME" : "S/MIME",
    "Manage S/MIME certificates" : "S/MIME 証明書の管理",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain!" : "現在のドメインでMailvelopeが有効になっています!",
    "Looking for a way to encrypt your emails?" : "あなたのメールを暗号化する方法をお探しですか?",
    "Enable Mailvelope for the current domain" : "現在のドメインのMailvelopeを有効にする",
    "Assistance features" : "アシスタンス機能",
    "About" : "Nextcloud について",
    "Keyboard shortcuts" : "キーボードショートカット",
    "Compose new message" : "新しいメッセージを作成する",
    "Newer message" : "新しいメッセージ",
    "Older message" : "古いメッセージ",
    "Toggle star" : "スターを切り替え",
    "Toggle unread" : "未読を切り替え",
    "Archive" : "アーカイブ",
    "Delete" : "削除",
    "Search" : "検索",
    "Send" : "送信",
    "Refresh" : "同期",
    "No certificate" : "証明書がありません",
    "Certificate updated" : "証明書が更新されました",
    "Could not update certificate" : "証明書を更新できませんでした",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - {expiryDate}まで有効",
    "Select an alias" : "エイリアスを選択する",
    "Select certificates" : "証明書を選択する",
    "Update Certificate" : "証明書を更新する",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "選択した証明書はサーバーによって信頼されていません。受信者が署名を確認できない可能性があります。",
    "Encrypt with S/MIME and send later" : "S/MIMEで暗号化して後で送信",
    "Encrypt with S/MIME and send" : " S/MIMEで暗号化するして送信する",
    "Encrypt with Mailvelope and send later" : "Mailvelopeで暗号化して後で送信",
    "Encrypt with Mailvelope and send" : "Mailvelopeで暗号化して送信する",
    "Send later" : "後で送信する",
    "Message {id} could not be found" : "メッセージ {id} が見つかりません",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "S/MIMEで署名または暗号化が選択されましたが、選択されたエイリアスの証明書がありません。メッセージは署名または暗号化されません。",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "既存の書式設定 (太字、斜体、下線、インライン画像など) はすべて削除されます。",
    "Turn off formatting" : "フォマットをオフ",
    "Turn off and remove formatting" : "書式設定をオフにして削除する",
    "Keep formatting" : "フォーマットを続ける",
    "From" : "差出人",
    "Select account" : "アカウントを選択",
    "To" : "宛先",
    "Cc/Bcc" : "Cc/Bcc",
    "Select recipient" : "受信先を選択する",
    "Contact or email address …" : "連絡先もしくはメールアドレス…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "件名",
    "Subject …" : "件名...",
    "This message came from a noreply address so your reply will probably not be read." : "このメッセージは送信専用アドレスから送信されたため、返信しても確認されない恐れがあります。",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "次の受信者にはS/MIME証明書がありません:{recipients}。",
    "The following recipients do not have a PGP key: {recipients}." : "次の受信者はPGPキーを持っていません: {recipients}",
    "Write message …" : "メッセージを書く…",
    "Saving draft …" : "下書きを保存しています",
    "Error saving draft" : "下書きの保存中にエラーが発生しました",
    "Draft saved" : "下書きを保存しました。",
    "Save draft" : "下書きを保存する",
    "Discard & close draft" : "下書きを破棄て閉じる",
    "Enable formatting" : "フォーマットを有効にする",
    "Disable formatting" : "フォーマットを無効化する",
    "Upload attachment" : "添付ファイルをアップロードする",
    "Add attachment from Files" : "ファイルから添付ファイルの追加",
    "Add share link from Files" : "ファイル から共有リンクを追加",
    "Smart picker" : "スマートピッカー",
    "Request a read receipt" : "開封の通知を要求する",
    "Sign message with S/MIME" : "S/MIMEでメッセージに署名する",
    "Encrypt message with S/MIME" : "S/MIMEでメッセージを暗号化する",
    "Encrypt message with Mailvelope" : "Mailvelopeでメッセージを暗号化",
    "Send now" : "今すぐ送信",
    "Tomorrow morning" : "明日の朝",
    "Tomorrow afternoon" : "明日の午後",
    "Monday morning" : "月曜日の朝",
    "Custom date and time" : "カスタム日時＆時間",
    "Enter a date" : "日付を入力してください",
    "Choose" : "選択",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["添付ファイルのサイズが 許可された{size}を超えています。代わりにリンクでファイルを共有してください。"],
    "Choose a file to add as attachment" : "添付として追加するファイルを選択",
    "Choose a file to share as a link" : "共有リンクにして送信するファイルを選択",
    "_{count} attachment_::_{count} attachments_" : ["{count} 個の添付ファイル"],
    "Untitled message" : "無題のメッセージ",
    "Expand composer" : "コンポーザーを展開する",
    "Close composer" : "コンポーザーを閉じる",
    "Confirm" : "承認",
    "Tag: {name} deleted" : "タグ:{name}削除済み",
    "An error occurred, unable to delete the tag." : "タグ削除を無効にする時エラーが発生しました",
    "The tag will be deleted from all messages." : "全てのメッセージからタグが削除されました",
    "Plain text" : "プレーンテキスト",
    "Rich text" : "リッチテキスト",
    "No messages in this folder" : "このフォルダーにメッセージはありません",
    "No messages" : "メッセージはありません",
    "Blind copy recipients only" : "BCC受信者のみ",
    "No subject" : "件名無し",
    "Later today – {timeLocale}" : "今日この後 – {timeLocale}",
    "Set reminder for later today" : "今日中にリマインダーを設定する",
    "Tomorrow – {timeLocale}" : "明日 – {timeLocale}",
    "Set reminder for tomorrow" : "明日のリマインダーを設定する",
    "This weekend – {timeLocale}" : "今週末 – {timeLocale}",
    "Set reminder for this weekend" : "今週末のリマインダーを設定する",
    "Next week – {timeLocale}" : "来週 – {timeLocale}",
    "Set reminder for next week" : "来週のリマインダーを設定する",
    "Could not delete message" : "メッセージを削除できませんでした",
    "Could not archive message" : "メッセージをアーカイブすることができませんでした",
    "Thread was snoozed" : "スレッドがスヌーズされました",
    "Could not snooze thread" : "スレッドをスヌーズできませんでした",
    "Thread was unsnoozed" : "スレッドがスヌーズ解除されました",
    "Could not unsnooze thread" : "スレッドのスヌーズを解除できませんでした",
    "This summary was AI generated" : "この要約はAIによって作成されました",
    "Encrypted message" : "暗号化済みメッセージ",
    "This message is unread" : "このメッセージは未読です",
    "Unfavorite" : "お気に入りから外す",
    "Favorite" : "お気に入り",
    "Unread" : "未読",
    "Read" : "読み込み",
    "Unimportant" : "重要ではない",
    "Mark not spam" : "迷惑メールとしない",
    "Mark as spam" : "迷惑メールとする",
    "Edit tags" : "タグを編集",
    "Snooze" : "スヌーズ",
    "Unsnooze" : "スヌーズを解除する",
    "Move thread" : "スレッドを移動する",
    "Archive thread" : "スレッドをアーカイブする",
    "Archive message" : "メッセージをアーカイブする",
    "Delete thread" : "スレッドを削除",
    "Delete message" : "メッセージを削除",
    "More actions" : "その他のアクション",
    "Back" : "戻る",
    "Set custom snooze" : "カスタムスヌーズを設定する",
    "Edit as new message" : "新しいメッセージとして編集",
    "Create event" : "イベントを作成",
    "Create task" : "タスクを作成する",
    "Download message" : "メッセージをダウンロードする",
    "Load more" : "さらに読み込む",
    "_Mark {number} read_::_Mark {number} read_" : ["{number} を既読としてマークします"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["{number} を未読としてマークする"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["{number} に重要なマークを付ける"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["{number} を重要でないとマークする"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["推奨されていない{number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["推奨 {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["未選択 {number}"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["{number}をスパムとしてマーク"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["{number}件をスパムでないとマーク"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["{number} のタグを編集"],
    "_Move {number} thread_::_Move {number} threads_" : ["{number}スレッドを移動する"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["{number} を添付ファイルとして転送"],
    "Report this bug" : "不具合を報告",
    "Event created" : "イベントを作成しました",
    "Could not create event" : "イベントを作成できませんでした。",
    "All day" : "終日",
    "Select calendar" : "カレンダーを選択する",
    "Description" : "説明",
    "Create" : "作成",
    "This event was updated" : "このイベントは更新されました",
    "{attendeeName} accepted your invitation" : "{attendeeName} があなたの招待を受けました",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} さんがあなたの招待を受けないです",
    "{attendeeName} declined your invitation" : "{attendeeName} があなたの招待から辞退しました",
    "{attendeeName} reacted to your invitation" : "{attendeeName} さんがあなたの招待にリアクションをしました",
    "Failed to save your participation status" : "あなたの参加ステータスを保存できませんでした",
    "You accepted this invitation" : "あなたはこの招待を受け入れました",
    "You tentatively accepted this invitation" : "あなたはこの招待を受け入れました",
    "You declined this invitation" : "あなたはこの招待を辞退しました",
    "You already reacted to this invitation" : "あなたはこの招待にはすでに反応しています",
    "You have been invited to an event" : "あなたはイベントに招待されました",
    "This event was cancelled" : "このイベントはキャンセルされました",
    "Save to" : "に保存",
    "Select" : "選択",
    "Comment" : "コメント",
    "Accept" : "承諾",
    "Decline" : "拒否",
    "Tentatively accept" : "暫定的に受け入れる",
    "More options" : "追加のオプション",
    "Could not remove internal address {sender}" : "内部アドレス {sender} を削除できませんでした",
    "Could not add internal address {address}" : "内部アドレス {sender} を追加できませんでした",
    "individual" : "個人",
    "domain" : "ドメイン",
    "Remove" : "削除",
    "email" : "メール",
    "Add internal address" : "内部アドレスを追加する",
    "Add internal email or domain" : "内部のメールアドレスまたはドメインを追加する",
    "Itinerary for {type} is not supported yet" : "{type} タイプの旅程はまだサポートされていません",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "このメッセージをアーカイブフォルダに移動したり、現在のフォルダから削除するは許可されていません",
    "Loading messages …" : "メッセージの読み込み中…",
    "Choose target folder" : "ターゲットフォルダーを選択",
    "No more submailboxes in here" : "サブメールボックスはありません",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "あなたの過去の操作を元にしてメールには自動的に重要マークがつけられます。最初のうちは重要マークを手動でつけたり外したりしてシステムに重要なメールを教える必要がありますが、精度は徐々に向上します。",
    "Messages sent by you that require a reply but did not receive one after a couple of days will be shown here." : "返信が必要なメッセージを送信したが、数日経っても返信がない場合は、ここに表示されます。",
    "Follow up" : "フォローアップ",
    "Follow up info" : "フォローアップ情報",
    "Important info" : "重要な情報",
    "Other" : "その他",
    "Could not send mdn" : "mdn送信ができませんでした",
    "The sender of this message has asked to be notified when you read this message." : "メッセージの送信者はあなたがこのメッセージを開封した通知を求めています。",
    "Notify the sender" : "送信者に通知する",
    "You sent a read confirmation to the sender of this message." : "メッセージの開封通知をメッセージの送信者へ送信しました。",
    "Message was snoozed" : "メッセージがスヌーズされました",
    "Could not snooze message" : "メッセージをスヌーズできませんでした",
    "Message was unsnoozed" : "メッセージがスヌーズ解除されました",
    "Could not unsnooze message" : "メッセージのスヌーズを解除できませんでした",
    "Forward" : "転送",
    "Move message" : "メッセージを移動",
    "Translate" : "翻訳",
    "Forward message as attachment" : "メッセージを添付ファイルとして転送する",
    "View source" : "ソースを表示",
    "Print message" : "メッセージを印刷する",
    "Download thread data for debugging" : "スレッドデータをデイバッグするためにダウンロードする",
    "Message body" : "メッセージ本文",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "警告:このメッセージのS/MIME署名は未検証です。送信者は誰かになりすましているかもしれません!",
    "Unnamed" : "名称未設定",
    "Embedded message" : "埋込メッセージ",
    "Attachment saved to Files" : "添付ファイルがファイルに保存されました",
    "Attachment could not be saved" : "添付ファイルが保存できませんでした",
    "calendar imported" : "カレンダーがインポートされました",
    "Choose a folder to store the attachment in" : "添付ファイルを保存するフォルダーを選択",
    "Import into calendar" : "カレンダーにインポート",
    "Download attachment" : "添付ファイルをダウンロード",
    "Save to Files" : "ファイルに保存",
    "Attachments saved to Files" : "添付ファイルをファイルに保存しました",
    "Error while saving attachments" : "添付ファイルを保存中にエラーが発生しました",
    "View fewer attachments" : "表示する添付ファイルの数を減らす",
    "Choose a folder to store the attachments in" : "添付ファイルを保存するフォルダーを選択してください",
    "Save all to Files" : "すべてファイルに保存",
    "Download Zip" : "ZIPファイルをダウンロード",
    "_View {count} more attachment_::_View {count} more attachments_" : ["{count}個の添付ファイルをもっと表示する"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "PGPで本文が暗号化されています。復号化するためにMailvelopeをインストールしてください。",
    "The images have been blocked to protect your privacy." : "画像はあなたのプライバシーを守るためにブロックされています。",
    "Show images" : "画像を表示する",
    "Show images temporarily" : "画像を一時的に表示",
    "Always show images from {sender}" : "{sender}からの画像を常に表示する",
    "Always show images from {domain}" : "{domain}からの画像を常に表示する",
    "Message frame" : "メッセージフレーム",
    "Quoted text" : "引用された文字",
    "Move" : "移動",
    "Moving" : "移動中",
    "Moving thread" : "スレッドを移動しています",
    "Moving message" : "メッセージを移動しています",
    "Remove account" : "アカウント削除",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "{email}のアカウントとキャッシュされたメールデータはNextcloudから削除されますが、メールプロバイダーからは削除されません。",
    "Remove {email}" : "{email} を削除",
    "Provisioned account is disabled" : "プロビジョニングされたアカウントは無効です",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "このアカウントを有効にするには、パスワードを使ってログインしてください。現在のセッションはシングルサインオンやWebAuthnなどのパスワードレス認証を使用しています。",
    "Show only subscribed folders" : "登録されているフォルダーのみ表示",
    "Add folder" : "フォルダーを追加",
    "Folder name" : "フォルダー名",
    "Saving" : "保存しています",
    "Move up" : "上に移動",
    "Move down" : "下に移動",
    "Show all subscribed folders" : "登録されているフォルダーを全て表示",
    "Show all folders" : "すべてのフォルダーを表示",
    "Collapse mailboxes" : "メールボックスを非表示",
    "_{total} message_::_{total} messages_" : ["{total} メッセージ"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{total} メッセージの内 {unread} 件が未開封"],
    "Loading …" : "読み込み中...",
    "All messages in mailbox will be deleted." : "メールボックスにある全てのメッセージが削除されます。",
    "Clear mailbox {name}" : "メールボックス{name}を削除する",
    "Delete folder" : "フォルダーを削除",
    "An error occurred, unable to rename the mailbox." : "エラー:メールボックスの名前を変更できませんでした。",
    "Please wait 10 minutes before repairing again" : "再度修復する前に10分間お待ちください。",
    "Mark all as read" : "すべて既読にする",
    "Mark all messages of this folder as read" : "このフォルダのすべてのメッセージを開封済みにする",
    "Add subfolder" : "サブフォルダを追加",
    "Rename" : "名前を変更",
    "Move folder" : "フォルダーを移動",
    "Clear cache" : "キャッシュをクリア",
    "Clear locally cached data, in case there are issues with synchronization." : "同期の問題を解消を解消するために、ローカルにキャッシュされたデータを消去",
    "Subscribed" : "購読",
    "Sync in background" : "バックグラウンドで同期",
    "Outbox" : "送信トレイ",
    "New message" : "新規メッセージ",
    "Edit message" : "メッセージを編集",
    "Draft" : "下書き",
    "Reply" : "返信",
    "Message saved" : "メッセージが保存されました",
    "Failed to save message" : "メッセージ保存が失敗しました",
    "Failed to save draft" : "下書き保存が失敗しました",
    "attachment" : "アタッチメント",
    "attached" : "添付",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "ToやCcで多くの受信者に送信しようとしています。受信者のアドレスを隠すためにBccを使用することを検討してください。",
    "You mentioned an attachment. Did you forget to add it?" : "添付ファイルがあると言及しました。追加するのを忘れましたか？",
    "Message discarded" : "メッセージは破棄されました",
    "Could not discard message" : "メッセージを破棄できませんでした",
    "Maximize composer" : "コンポーザーを最大化する",
    "Minimize composer" : "コンポーザーを最小化する",
    "Error sending your message" : "メッセージ送信エラー",
    "Retry" : "再試行",
    "Warning sending your message" : "メッセージを送信する際の警告",
    "Send anyway" : "送信",
    "Autoresponder off" : "自動応答オフ",
    "Autoresponder on" : "自動応答オン",
    "Autoresponder follows system settings" : "自動応答はシステム設定に従います",
    "The autoresponder follows your personal absence period settings." : "自動返信はあなたが不在の時指定した時間に返信します",
    "Edit absence settings" : "不在設定を編集する",
    "First day" : "初日",
    "Last day (optional)" : "最終日(オプション)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${件名}は、あなたが返信するメッセージの件名に置き換えられます",
    "Message" : "メッセージ",
    "Oh Snap!" : "おっと！",
    "Save autoresponder" : "自動応答を保存する",
    "Could not open outbox" : "送信トレイを開けませんでした",
    "Pending or not sent messages will show up here" : "保留中または未送信のメッセージはここに表示されます",
    "Mail server error" : "メールサーバーエラー",
    "Message could not be sent" : "メッセージを送信できませんでした",
    "Message deleted" : "メッセージを削除しました",
    "Phishing email" : "フィッシングメール",
    "This email might be a phishing attempt" : "このメールはフィッシングの可能性があります",
    "Hide suspicious links" : "不審なリンクを隠す",
    "Show suspicious links" : "不審なリンクを表示する",
    "link text" : "リンクテキスト",
    "Copied email address to clipboard" : "メールアドレスをクリップボードにコピーしました",
    "Could not copy email address to clipboard" : "クリップボードにメールアドレスをコピーすることができませんでした",
    "Contacts with this address" : "このアドレスに連絡先",
    "Add to Contact" : "連絡先に追加",
    "New Contact" : "新しい連絡先",
    "Copy to clipboard" : "クリップボードにコピー",
    "Contact name …" : "連絡先の名前…",
    "Add" : "追加",
    "Show less" : "表示を減らす",
    "Show more" : "表示を増やす",
    "Clear" : "クリア",
    "Close" : "閉じる",
    "Search parameters" : "パラメータを検索する",
    "Search subject" : "件名を検索する",
    "Body" : "本文",
    "Search body" : "本文を検索する",
    "Date" : "日付",
    "Pick a start date" : "開始日を選択してください",
    "Pick an end date" : "終了日を選択してください",
    "Select senders" : "送信先を選択する",
    "Select recipients" : "受信先を選択する",
    "Select CC recipients" : "CC 受信者を選択する",
    "Select BCC recipients" : "BCC 受信者を選択する",
    "Tags" : "タグ",
    "Select tags" : "タグを選択",
    "Marked as" : "マークする",
    "Has attachments" : "添付ファイルがあります",
    "Mentions me" : "私にメンション",
    "Has attachment" : "添付済み",
    "Last 7 days" : "7日以内",
    "From me" : "私から",
    "Enable mail body search" : "メール本文の検索を有効化する",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieveはメールボックス用のフィルターを書くための強力な言語です。お使いのメールサービスが対応していれば、MailでSieveスクリプトを管理することができます。また、オートレスポンダーとフィルターを使用するにはSieveが必要です。",
    "Enable sieve filter" : "sieveフィルタを有効にする",
    "Sieve host" : "ホストを分別する",
    "Sieve security" : "セキュリティ検討",
    "Sieve Port" : "Sieveポート",
    "Sieve credentials" : "クレデンシャルの仕分け",
    "IMAP credentials" : "IMAPクレデンシャル",
    "Custom" : "カスタム",
    "Sieve User" : "Sieveユーザー",
    "Sieve Password" : "ふるいパスワード",
    "Oh snap!" : "おっと！",
    "Save sieve settings" : "保存先仕分けの設定",
    "The syntax seems to be incorrect:" : "構文が間違っています:",
    "Save sieve script" : "sieve スクリプトを保存する",
    "Signature …" : "署名…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "あなたの署名は2MBを超えています。エディターのパフォーマンスに影響する可能性があります。",
    "Save signature" : "署名を保存",
    "Place signature above quoted text" : "引用文の上に署名を配置する",
    "Message source" : "メッセージソース",
    "An error occurred, unable to rename the tag." : "エラー:タグの名前を変更できませんでした",
    "Edit name or color" : "名前または色を編集する",
    "Saving new tag name …" : "新しいタグ名を保存中...",
    "Delete tag" : "タグを削除",
    "Set tag" : "タグを設定する",
    "Unset tag" : "タグを削除する",
    "Tag name is a hidden system tag" : "タグ名は非表示のシステムタグです",
    "Tag already exists" : "タグはすでに存在します",
    "Tag name cannot be empty" : "タグ名は空にできません",
    "An error occurred, unable to create the tag." : "エラー:タグを作成できませんでした",
    "Add default tags" : "デフォルトのタグを追加する",
    "Add tag" : "タグを追加",
    "Saving tag …" : "タグを保存中しています...",
    "Task created" : "タスクを作成しました",
    "Could not create task" : "タスクを作成はできなかったです",
    "No calendars with task list support" : "タスクリストをサポートするカレンダーはありません",
    "Summarizing thread failed." : "スレッドの概要作成が失敗しました",
    "Could not load your message thread" : "メッセージを読み込めませんでした",
    "The thread doesn't exist or has been deleted" : "スレッドがありませんまたは削除されています",
    "Loading thread" : "スレッドを読み込み中",
    "Not found" : "見つかりませんでした",
    "Encrypted & verified " : "暗号化済み＆検証済み",
    "Signature verified" : "署名が検証されました",
    "Signature unverified " : "署名が未検証です",
    "This message was encrypted by the sender before it was sent." : "このメッセージは送信前に送信者よって暗号化されました。",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "このメッセージには、検証済みのデジタルS/MIME署名が含まれています。メッセージは送信後に変更されていません。",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "このメッセージには未検証のデジタルS/MIME署名が含まれています。メッセージが送信後に変更されたか、署名者の証明書が信頼されていない可能性があります。",
    "Reply all" : "全て返信する",
    "Unsubscribe request sent" : "購読解除リクエストが送信されました",
    "Could not unsubscribe from mailing list" : "メーリングリストから登録解除できませんでした",
    "Please wait for the message to load" : "メッセージが読み込まれるまでお待ちください",
    "Disable reminder" : "リマインダを無効にする",
    "Unsubscribe" : "購読解除",
    "Reply to sender only" : "送信者のみに返信",
    "Mark as unfavorite" : "お気に入りから外す",
    "Mark as favorite" : "お気に入りにする",
    "Mark as unread" : "未読にする",
    "Mark as read" : "既読にする",
    "Unsubscribe via link" : "リンク経由で購読を解除する",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "リスト{sender}から全ての配信メッセージを停止する",
    "Send unsubscribe email" : "配信停止メールを送信する",
    "Unsubscribe via email" : "メールで購読を解除する",
    "{name} Assistant" : "{name}アシスタント",
    "Go to latest message" : "最新のメッセージへ移動",
    "Go to newest message" : "一番新しいメッセージへ移動",
    "Thread summary" : "スレッドの概要",
    "Please select languages to translate to and from" : "翻訳する言語を選択してください",
    "The message could not be translated" : "メッセージは翻訳できませんでした",
    "Translation copied to clipboard" : "翻訳をクリップボードにコピーしました",
    "Translation could not be copied" : "翻訳をコピーできませんでした",
    "Translate message" : "メッセージの翻訳",
    "Source language to translate from" : "翻訳元の言語",
    "Translate from" : "原文の言語",
    "Target language to translate into" : "翻訳先の言語",
    "Translate to" : "翻訳先",
    "Translating" : "翻訳する",
    "Copy translated text" : "翻訳されたテキストをコピー",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "フィールドを空のままにするか、0に設定して、ごみ箱の保持を無効にします。ごみ箱を有効にしてから削除したメールのみ処理されます。",
    "Could not remove trusted sender {sender}" : "信頼できる送信者 {sender} を削除できませんでした",
    "No senders are trusted at the moment." : "現在、信頼できる送信者はありません。",
    "Untitled event" : "無題のイベント",
    "(organizer)" : "（主催者）",
    "Import into {calendar}" : "{calendar} へインポート",
    "Event imported into {calendar}" : "イベントが {calendar} にインポートされました",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{depAirport} から {arrAirport} 行きのフライト番号 {flightNr}",
    "Airplane" : "飛行機",
    "Reservation {id}" : "予約ID {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車番号 {trainNr}",
    "Train from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車",
    "Train" : "列車",
    "Delete action" : "アクションを削除",
    "Flag" : "フラグ",
    "The stop action ends all processing" : "stop アクションは、すべての処理を終了します",
    "Recipient" : "受信者",
    "Delete filter" : "フィルターを削除",
    "Delete mail filter {filterName}?" : "メールフィルター{filterName}を削除しますか？",
    "Are you sure to delete the mail filter?" : "メールフィルターを削除してよろしいですか？",
    "New filter" : "新しいフィルター",
    "Filter saved" : "フィルターを保存しました",
    "Could not save filter" : "フィルターを保存できませんでした",
    "Filter deleted" : "フィルターを削除しました",
    "Could not delete filter" : "フィルターを削除できませんでした",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "メールの混乱をコントロールしましょう。フィルタを使えば、重要なものに優先順位をつけ、乱雑さを解消できます。",
    "Filter is active" : "フィルターが有効",
    "Filter is not active" : "フィルターが無効",
    "Operator" : "条件",
    "contains" : "を含む",
    "matches" : "一致",
    "Delete test" : "テストを削除",
    "Update mail filter" : "メールフィルターを更新する",
    "Filter name" : "フィルター名",
    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "テストは、Subject（メールの件名）、From（送信者）、To（受信者）などのフィールドを対象として、メールサーバー上の受信メールに適用されます。以下の演算子を使用して、これらのフィールドの条件を定義できます：",
    "An exact match. The field must be identical to the provided value." : "完全一致。フィールドは提供された値と同一でなければなりません。",
    "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "部分文字列のマッチ。提供された値がそのフィールドに含まれる場合にマッチする。例えば、「report 」は 「port 」にマッチする。",
    "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ワイルドカードを使ったパターン・マッチ。記号 「*」は任意の文字数（ない場合も含む）を表し、「? 」は正確に1文字を表す。例えば、「*report*」は 「Business report 2024 」にマッチする。",
    "Actions are triggered when the specified tests are true. The following actions are available:" : "アクションは、指定されたテストが真であるときにトリガーされる。以下のアクションが利用可能です：",
    "Moves the message into a specified folder." : "メッセージを指定したフォルダーに移動します。",
    "Adds a flag to the message." : "メッセージにフラグを追加する。",
    "Halts the execution of the filter script. No further filters with will be processed after this action." : "フィルタースクリプトの実行を停止する。この操作の後、それ以降のフィルターは処理されません。",
    "Priority" : "優先度",
    "Enable filter" : "フィルターを有効にする",
    "Save filter" : "フィルターを保存する",
    "Successfully updated config for \"{domain}\"" : " \"{domain}\"の設定が正常に更新されました",
    "Error saving config" : "設定の保存中にエラーが発生しました",
    "Saved config for \"{domain}\"" : "\"{domain}\"の設定を保存しました",
    "Could not save provisioning setting" : "プロビジョニング設定を保存できませんでした",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} 個のアカウントが正常にプロビジョニングされました。"],
    "There was an error when provisioning accounts." : "アカウントのプロビジョニング時にエラーが発生しました。",
    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "{domain}のアカウントが正常に削除され、プロビジョニング解除されました",
    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\"のアカウントプロビジョニングを解除と削除すする際にエラーが発生しました。",
    "Could not save default classification setting" : "デフォルトの分類設定を保存できませんでした",
    "Mail app" : "メールアプリ",
    "The mail app allows users to read mails on their IMAP accounts." : "メールアプリで、ユーザーはIMAPアカウントでメールを読むことができます。",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "ここでは、インスタンス全体の設定を確認できます。ユーザー固有の設定は、アプリ自体 (左下隅) にあります。",
    "Account provisioning" : "アカウントをプロビジョニングする",
    "A provisioning configuration will provision all accounts with a matching email address." : "プロビジョニング設定では、一致する電子メールアドレスを持つ全てのアカウントがプロビジョニングされます。",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "プロビジョニングドメインフィールドでワイルドカード (*) を使用すると、他の設定と一致しない限り、すべてのユーザに適用される設定が作成されます。",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "プロビジョニングメカニズムでは、ワイルドカードドメイン設定よりも特定のドメイン設定が優先されます。",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "ユーザが別の設定ですでにプロビジョニングされた後に一致する新しい設定が見つかった場合、新しい設定が優先され、ユーザはその設定で再プロビジョニングされます。",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "ドメインごとに設定できるのは1つだけで、ワイルドカードドメイン設定も1つだけです。",
    "These settings can be used in conjunction with each other." : "これらの設定は、相互に組み合わせて使用できます。",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "すべてのユーザーに対して 1 つのドメインのみをプロビジョニングする場合は、ワイルドカード (*) を使用します。",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "この設定は、組織のNextcloudとメールサーバーに同じユーザーバックエンドを使用している場合にのみ意味があります。",
    "Provisioning Configurations" : "設定をプロビジョニングする",
    "Add new config" : "新しい設定を追加",
    "Provision all accounts" : "全てのアカウントをプロビジョニングする",
    "Allow additional mail accounts" : "追加のメールアカウントを許可する",
    "Allow additional Mail accounts from User Settings" : "ユーザー設定からメールアカウント追加を許可する",
    "Enable text processing through LLMs" : "LLMによるテキスト処理を有効にする",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mailアプリは、設定された大規模言語モデルの助けを借りてユーザーデータを処理し、スレッドの要約、スマート返信、イベントの議題などの支援機能を提供します。",
    "Enable LLM processing" : "LLM処理を有効にする",
    "Enable classification by importance by default" : "デフォルトでメールの重要度を仕分けする",
    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "Mailアプリは、機械学習を利用して受信メールを重要度別に分類できます。この機能はデフォルトで有効になっていますが、ここではデフォルトで無効にできます。個々のユーザーは、自分のアカウントの機能を切り替えることができます。",
    "Enable classification of important mails by default" : "デフォルトで重要なメールの仕分けを有効化する",
    "Anti Spam Service" : "スパム対策サービス",
    "You can set up an anti spam service email address here." : "あなたがスパム対策サービスしたいメールアドレスをここで設定できます",
    "Any email that is marked as spam will be sent to the anti spam service." : "スパムとしてマークされたメールはすべてスパム対策サービスに送信されます。",
    "Gmail integration" : "Gmailと統合する",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmailでは、IMAP経由でメールにアクセスすることができます。セキュリティ上の理由から、このアクセスはOAuth 2.0接続、または二要素認証とアプリのパスワードを使用するGoogleアカウントでのみ可能です。",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloudコンソールで\"Webアプリケーション\"の新しいクライアントIDを登録する必要があります。承認済みリダイレクトURIとしてURL{url}を追加します。",
    "Microsoft integration" : "Microsoft と統合する",
    "Successfully set up anti spam email addresses" : "スパム対策メールアドレスの設定が成功しました",
    "Error saving anti spam email addresses" : "スパム対策報告メールを保存する時エラーがでました",
    "Successfully deleted anti spam reporting email" : "スパム対策報告メールを正常に削除しました",
    "Error deleting anti spam reporting email" : "スパム対策報告メールを削除エラー",
    "Anti Spam" : "アンチスパム",
    "Add the email address of your anti spam report service here." : "あなたのスパム対策報告サービスするメールアドレスをここに追加してください",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "この設定を使用すると、ユーザーが \"スパムとしてマーク\" をクリックしたときに、スパムレポートサーバーにレポート電子メールが送信されます。",
    "The original message will be attached as a \"message/rfc822\" attachment." : "元のメッセージは \"message/rfc822\" の形式で添付されます。",
    "\"Mark as Spam\" Email Address" : "\"スパムメールマークではない\"メールアドレス",
    "\"Mark Not Junk\" Email Address" : "\"迷惑メールマークではない\"メールアドレス",
    "Reset" : "リセット",
    "Google integration configured" : "Google統合が設定されました",
    "Could not configure Google integration" : "Google 統合の設定はできませんでした",
    "Google integration unlinked" : "Google統合が解除されました",
    "Could not unlink Google integration" : "Google 統合のリンクを解除できませんでした",
    "Client ID" : "クライアント ID",
    "Client secret" : "クライアントシークレット",
    "Unlink" : "アンリンク",
    "Microsoft integration configured" : "Tenant統合が設定されました",
    "Could not configure Microsoft integration" : "Microsoft統合の設定ができませんでした",
    "Microsoft integration unlinked" : "Microsoft 統合が解除されました",
    "Could not unlink Microsoft integration" : "Microsoft 統合のリンクを解除できませんでした",
    "Tenant ID (optional)" : "テナントID（オプション）",
    "Domain Match: {provisioningDomain}" : "ドメイン一致:{provisioningDomain}",
    "Email: {email}" : "メール: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port}の{user} ({ssl} 暗号化)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port}の{user} ({ssl} 暗号化)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "シーブ: {user} on {host}:{port} ({ssl} 暗号化)",
    "Configuration for \"{provisioningDomain}\"" : " \"{provisioningDomain}\"の設定",
    "Provisioning domain" : "プロビジョニングドメイン",
    "Email address template" : "メールアドレステンプレート",
    "IMAP" : "IMAP",
    "User" : "ユーザー",
    "Host" : "ホスト",
    "Port" : "ポート",
    "SMTP" : "SMTP",
    "Master password" : "マスターパスワード",
    "Use master password" : "マスターパスワードを使用する",
    "Sieve" : "仕分け",
    "Enable sieve integration" : "sieve統合を有効にする",
    "LDAP aliases integration" : "LDAP エイリアスの統合",
    "Enable LDAP aliases integration" : "LDAPエイリアス統合を有効にする",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAPエイリアス統合は、設定されたLDAPディレクトリから属性を読み取り、電子メールエイリアスをプロビジョニングします。",
    "LDAP attribute for aliases" : "エイリアスの LDAP 属性",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "電子メールエイリアスをプロビジョニングするためのマルチ値属性。値ごとにエイリアスが作成されます。LDAPディレクトリにないNextcloudに存在するエイリアスは削除されます。",
    "Save Config" : "設定を保存",
    "Unprovision & Delete Config" : "プロビジョニング解除と設定の削除",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* USERID%と %E MAIL%は、ユーザーのUIDとEメールに置き換えられます。",
    "With the settings above, the app will create account settings in the following way:" : "上記の設定では、アプリは次の方法でアカウント設定を作成します：",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "指定されたPKCS#12証明書には、少なくとも一つの証明書と一つの秘密鍵が含まれている必要があります。",
    "Failed to import the certificate. Please check the password." : "証明書のインポートが失敗しました。パスワードをチェックしてください",
    "Certificate imported successfully" : "証明書のインポートが成功しました",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "証明書のインポートに失敗しました。秘密鍵が証明書と一致し、パスフレーズで保護されていないことを確認してください。",
    "Failed to import the certificate" : "証明書のインポートするが失敗した",
    "S/MIME certificates" : "S/MIME証明書",
    "Certificate name" : "証明書名",
    "E-mail address" : "メールアドレス",
    "Valid until" : "有効期限",
    "Delete certificate" : "証明書を削除する",
    "No certificate imported yet" : "証明書はまだインポートされていません",
    "Import certificate" : "証明書をインポートする",
    "Import S/MIME certificate" : "S/MIME 証明書をインポートする",
    "PKCS #12 Certificate" : "PKCS #12 証明書",
    "PEM Certificate" : "PEM証明書",
    "Certificate" : "証明",
    "Private key (optional)" : "秘密鍵（オプション）",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "秘密鍵は、この証明書を使用して署名および暗号化された電子メールを送信する場合にのみ必要です。",
    "Submit" : "提出する",
    "Account connected" : "アカウントに接続しました",
    "You can close this window" : "このウィンドウを閉じることができます",
    "Connect your mail account" : "あなたのメールアカウントに接続",
    "To add a mail account, please contact your administrator." : "メールアカウントを追加するためには、あなたの管理者に連絡してください",
    "All" : "すべて",
    "Drafts" : "下書き",
    "Favorites" : "お気に入り",
    "Priority inbox" : "優先受信箱",
    "All inboxes" : "すべての受信トレイ",
    "Inbox" : "受信箱",
    "Junk" : "迷惑メール",
    "Sent" : "送信済み",
    "Trash" : "ゴミ箱",
    "Connect OAUTH2 account" : "OAUTH2 アカウントと接続する",
    "Error while sharing file" : "共有中にエラーが発生しました",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n個の新しいメッセージ\nfrom{from}"],
    "Nextcloud Mail" : "Nextcloud メール",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "進行中のメッセージが既にあります。続行すると、保存されていないすべての変更が失われます。",
    "Discard changes" : "変更を破棄する",
    "Discard unsaved changes" : "保存されていない変更を破棄する",
    "Keep editing message" : "メッセージの編集を続ける",
    "Attachments were not copied. Please add them manually." : "添付ファイルはコピーできませんでした。手動で追加してください。",
    "Could not create snooze mailbox" : "スヌーズメールボックスを作成できませんでした",
    "Message sent" : "メッセージ送信済",
    "Could not send message" : "メッセージを送信できませんでした",
    "Could not load {tag}{name}{endtag}" : "{tag} {name} {endtag}を読み込めませんでした",
    "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag} の読み込み中に問題が発生しました",
    "Could not load your message" : "あなたのメッセージを読み込めませんでした",
    "Could not load the desired message" : "目的のメッセージを読み込めませんでした",
    "Could not load the message" : "メッセージを読み込めませんでした",
    "Error loading message" : "メッセージ読み込みエラー",
    "Forwarding to %s" : "%s への転送",
    "Click here if you are not automatically redirected within the next few seconds." : "数秒以内に自動的にリダイレクトされない場合は、ここをクリックしてください。",
    "Redirect" : "リダイレクト",
    "The link leads to %s" : "リンクが %s につながります",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ページにアクセスしたくない場合は、<a href=\"%s\">メール</a>に戻ることができます",
    "Continue to %s" : "%s にリダイレクトする",
    "Mailbox search" : "メールボックスの検索",
    "Install Mailvelope browser extension by clicking here" : "メールブラウザー拡張機能インストールしたい場合はここをクリックしてください",
    "No messages in this mailbox" : "このメールボックスにメッセージはありません",
    "No trash mailbox configured" : "ゴミ箱メールボックスが設定されていません",
    "Draft: " : "下書き",
    "To archive a message please configure an archive mailbox in account settings" : "メッセージをアーカイブするためにはアカウント設定からアーカイブメールボックスの設定をしてください",
    "Could not open mailbox" : "メールボックスを開けませんでした",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "メールをインデックスしています。大きいメールボックスの場合はしばらくお待ちください。",
    "Choose target mailbox" : "対象のメールボックスを選択してください",
    "Show only subscribed mailboxes" : "購読したメールボックスのみ表示",
    "Add mailbox" : "メールボックスを追加",
    "Mailbox name" : "メールボックス名",
    "Show all subscribed mailboxes" : "購読したメールボックスを全て表示",
    "Show all mailboxes" : "全てのメールボックスを表示",
    "Clear mailbox" : "メールボックスをクリアする",
    "The mailbox and all messages in it will be deleted." : "メールボックスと中にある全てのメッセージが削除されます。",
    "Delete mailbox" : "メールボックスを削除",
    "Delete mailbox {name}" : "メールボックス「{name}」を削除",
    "Mark all messages of this mailbox as read" : "このフォルダのすべてのメッセージを開封済みにする",
    "Add submailbox" : "サブメールボックスを追加",
    "Move mailbox" : "メールボックスを移動する",
    "Repair mailbox" : "メールボックスを修復する",
    "No sent mailbox configured. Please pick one in the account settings." : "送信済みのメールボックスはまだ設定されていません。アカウント設定から設定してください",
    "Could not copy to \"Sent\" mailbox" : "\"送信済み\"メールボックスにコピーできませんでした",
    "Copy to \"Sent\" Mailbox" : "「送信済み」メールボックスにコピー",
    "Copy to Sent Mailbox" : "送信済みのメールボックスにコピーする",
    "Search in mailbox" : "メールボックス内の検索",
    "If all tests pass, then the actions will be executed" : "すべてのテストがパスすれば、アクションが実行されます",
    "If one test pass, then the actions will be executed" : "テストが1つでもパスすれば、アクションが実行されます",
    "Tests" : "テスト",
    "New test" : "新しいテスト",
    "Actions" : "アクション",
    "New action" : "新しいアクション",
    "Message copied to \"Sent\" mailbox" : "メッセージが\"送信済み\"メールボックスにコピーされました",
    "Could not copy message to \"Sent\" mailbox" : "メッセージを”送信済み”メールボックスにコピーできませんでした"
},
"nplurals=1; plural=0;");
